@@ -103,7 +103,7 @@ static void translateMasksAndMaps(devinfo& dev)
     dev.chanIDs.clear();
 
     if (dev.channel_map.channels != dev.volume.channels) {
-        qCCritical(KMIX_LOG) << "Hiddeous Channel mixup map says " << dev.channel_map.channels << ", volume says: " << dev.volume.channels;
+        qCCritical(KMIX_LOG) << "Hideous Channel mixup map says " << dev.channel_map.channels << ", volume says: " << dev.volume.channels;
         return;
     }
     if (1 == dev.channel_map.channels && PA_CHANNEL_POSITION_MONO == dev.channel_map.map[0]) {
@@ -477,7 +477,7 @@ void ext_stream_restore_read_cb(pa_context *c, const pa_ext_stream_restore_info
             rule.mute = false;
             rule.device = "";
             s_RestoreRules[KMIXPA_EVENT_KEY] = rule;
-            qCDebug(KMIX_LOG) << "Initialising restore rule for new user: " << i18n("Event Sounds");
+            qCDebug(KMIX_LOG) << "Initializing restore rule for new user: " << i18n("Event Sounds");
         }
 
         if (s_mixers.contains(KMIXPA_APP_PLAYBACK)) {
@@ -789,7 +789,7 @@ void Mixer_PULSE::emitControlsReconfigured()
 	 *  a) It seems there seems to be some object deletion hazard with a QMenu (the one for "move stream")
 	 *  b)  I do not see why executing it Queued is better, because you can never know when it is actually being
 	 *      executed: it could be "right now". It looks like Qt currently executes it after the QMenu hazard has
-	 *      resolved itselves miracously.
+	 *      resolved itself miraculously.
 	 *  c) I am definitely strongly opposed on this "execute later" approach. It is pure gambling IMO and might be
 	 *     broken any time (from DEBUG to RELEASE build, or by a new Qt or KDE version).
 	 *
@@ -909,29 +909,28 @@ void Mixer_PULSE::removeAllWidgets()
 
 bool Mixer_PULSE::addDevice(devinfo& dev, bool isAppStream)
 {
-    if (dev.chanMask == Volume::MNONE)
-        return false;
+    if (dev.chanMask == Volume::MNONE) return false;
 
-        MixSet *ms = 0;
-        if (m_devnum == KMIXPA_APP_PLAYBACK && s_mixers.contains(KMIXPA_PLAYBACK))
-            ms = s_mixers[KMIXPA_PLAYBACK]->getMixSet();
-        else if (m_devnum == KMIXPA_APP_CAPTURE && s_mixers.contains(KMIXPA_CAPTURE))
-            ms = s_mixers[KMIXPA_CAPTURE]->getMixSet();
+    MixSet *ms = nullptr;
+    if (m_devnum == KMIXPA_APP_PLAYBACK && s_mixers.contains(KMIXPA_PLAYBACK))
+        ms = s_mixers[KMIXPA_PLAYBACK]->getMixSet();
+    else if (m_devnum == KMIXPA_APP_CAPTURE && s_mixers.contains(KMIXPA_CAPTURE))
+        ms = s_mixers[KMIXPA_CAPTURE]->getMixSet();
 
-        int maxVol = GlobalConfig::instance().data.volumeOverdrive ? PA_VOLUME_UI_MAX : PA_VOLUME_NORM;
-        Volume v(maxVol, PA_VOLUME_MUTED, true, false);
-        v.addVolumeChannels(dev.chanMask);
-        setVolumeFromPulse(v, dev);
-        MixDevice* md = new MixDevice( _mixer, dev.name, dev.description, dev.icon_name, ms);
-        if (isAppStream)
-            md->setApplicationStream(true);
+    int maxVol = GlobalConfig::instance().data.volumeOverdrive ? PA_VOLUME_UI_MAX : PA_VOLUME_NORM;
+    Volume v(maxVol, PA_VOLUME_MUTED, true, false);
+    v.addVolumeChannels(dev.chanMask);
+    setVolumeFromPulse(v, dev);
+    MixDevice* md = new MixDevice( _mixer, dev.name, dev.description, dev.icon_name, ms);
+    if (isAppStream)
+        md->setApplicationStream(true);
 
 //        qCDebug(KMIX_LOG) << "Adding Pulse volume " << dev.name << ", isCapture= "
 //                      << (m_devnum == KMIXPA_CAPTURE || m_devnum == KMIXPA_APP_CAPTURE)
 //                      << ", isAppStream= " << isAppStream << "=" << md->isApplicationStream() << ", devnum=" << m_devnum;
-        md->addPlaybackVolume(v);
-        md->setMuted(dev.mute);
-        m_mixDevices.append(md->addToPool());
+    md->addPlaybackVolume(v);
+    md->setMuted(dev.mute);
+    m_mixDevices.append(md->addToPool());
     return true;
 }
 
@@ -1404,7 +1403,7 @@ bool Mixer_PULSE::moveStream( const QString& id, const QString& destId ) {
             pa_operation* o;
             if (!(o = pa_ext_stream_restore_write(s_context, PA_UPDATE_REPLACE, &info, 1, true, NULL, NULL))) {
                 qCWarning(KMIX_LOG) <<  "pa_ext_stream_restore_write() failed" << info.channel_map.channels << info.volume.channels << info.name;
-                return Mixer::ERR_READ;
+                return false;
             }
             pa_operation_unref(o);
         }
