@@ -77,14 +77,14 @@ friend class MixDevice;
 
                   CHIDMAX      = 8 };
 
-    static char ChannelNameForPersistence[9][30];
-    static QString ChannelNameReadable[9];
+    static QString channelNameForPersistence(ChannelID id);
+    static QString channelNameReadable(ChannelID id);
 
     enum VolumeType { PlaybackVT = 0 , CaptureVT = 1 };
 
     enum VolumeTypeFlag { Playback = 1, Capture = 2, Both = 3 };
 
-    // regular constructor (old, deprecsted)
+    // regular constructor (old, deprecated)
     //Volume( ChannelMask chmask, long maxVolume, long minVolume, bool hasSwitch, bool isCapture );
     // regular constructor
     Volume(long maxVolume, long minVolume, bool hasSwitch, bool isCapture );
@@ -143,9 +143,8 @@ friend class MixDevice;
     friend std::ostream& operator<<(std::ostream& os, const Volume& vol);
     friend QDebug operator<<(QDebug os, const Volume& vol);
 
-    // _channelMaskEnum[] and the following elements moved to public seection. operator<<() could not
+    // _channelMaskEnum[] and the following elements moved to public section. operator<<() could not
     // access it, when private. Strange, as operator<<() is declared friend.
-    static int    _channelMaskEnum[9];
     QMap<Volume::ChannelID, VolumeChannel> getVolumes() const;
     QMap<Volume::ChannelID, VolumeChannel> getVolumesWhenActive() const;
     long volumeStep(bool decrease);
@@ -160,7 +159,7 @@ protected:
 
     long          _minVolume;
     long          _maxVolume;
-   // setSwitch() and isSwitchActivated() are tricky. No regular class (incuding the Backends) shall use
+   // setSwitch() and isSwitchActivated() are tricky. No regular class (including the Backends) shall use
    // these functions. Our friend class MixDevice will handle that gracefully for us.
    void setSwitch( bool active );
    bool isSwitchActivated() const  // TODO rename to isActive()
