@@ -157,7 +157,7 @@ void MDWSlider::createShortcutActions()
         This is a bug according to the thread "Global shortcuts are saved with their text-name and not their action-name - Bug?" on kcd.
         I work around this by using a text with setText() that is unique, but still readable to the user.
     */
-    QString actionSuffix  = QString(" - %1, %2").arg( mixDevice()->readableName() ).arg( mixDevice()->mixer()->readableName() );
+    QString actionSuffix  = QString(" - %1, %2").arg( mixDevice()->readableName(), mixDevice()->mixer()->readableName() );
     QAction *bi, *bd, *bm;
 
     // -1- INCREASE VOLUME SHORTCUT -----------------------------------------
@@ -206,7 +206,7 @@ QSize MDWSlider::sizeHint() const
  * This method is a helper for users of this class who would like
  * to show multiple MDWSlider, and align the sliders.
  * It returns the "height" (if vertical) of this widgets label.
- * Warning: Line wraps are computed for a fixed size (100), this may be unaccurate in case,
+ * Warning: Line wraps are computed for a fixed size (100), this may be inaccurate in case,
  * the widgets have different sizes.
  */
 int MDWSlider::labelExtentHint() const
@@ -350,9 +350,9 @@ void MDWSlider::createWidgets( bool showMuteButton, bool showCaptureLED, bool in
     QString captureTooltipText( i18n( "Capture/Uncapture %1", m_mixdevice->readableName() ) );
     QString muteTooltipText( i18n( "Mute/Unmute %1", m_mixdevice->readableName() ) );
     if (includeMixerName) {
-        tooltipText = QString( "%1\n%2" ).arg( m_mixdevice->mixer()->readableName() ).arg( tooltipText );
-        captureTooltipText = QString( "%1\n%2" ).arg( m_mixdevice->mixer()->readableName() ).arg( captureTooltipText );
-        muteTooltipText = QString( "%1\n%2" ).arg( m_mixdevice->mixer()->readableName() ).arg( muteTooltipText );
+        tooltipText = QString( "%1\n%2" ).arg( m_mixdevice->mixer()->readableName(), tooltipText );
+        captureTooltipText = QString( "%1\n%2" ).arg( m_mixdevice->mixer()->readableName(), captureTooltipText );
+        muteTooltipText = QString( "%1\n%2" ).arg( m_mixdevice->mixer()->readableName(), muteTooltipText );
     }
 
       // case of vertical sliders:
@@ -579,7 +579,7 @@ void MDWSlider::addSliders( QBoxLayout *volLayout, char type, Volume& vol,
 
 		QString subcontrolTranslation;
 		if ( type == 'c' ) subcontrolTranslation += i18n("Capture") + ' ';
-		subcontrolTranslation += Volume::ChannelNameReadable[vc.chid]; //Volume::getSubcontrolTranslation(chid);
+		subcontrolTranslation += Volume::channelNameReadable(vc.chid);
 		subcontrolLabel = createLabel(this, subcontrolTranslation, volLayout, true);
 
 		QAbstractSlider* slider;
@@ -998,8 +998,8 @@ void MDWSlider::increaseVolume()
 }
 
 /**
- * This slot is called on a Keyboard Shortcut event, except for the XF86Audio* shortcuts which hare handeled by the
- * KMixWindow class. So for 99.9% of all users, this methos is never called.
+ * This slot is called on a Keyboard Shortcut event, except for the XF86Audio* shortcuts which hare handled by the
+ * KMixWindow class. So for 99.9% of all users, this method is never called.
  */
 void MDWSlider::decreaseVolume()
 {
@@ -1139,12 +1139,12 @@ void MDWSlider::updateAccesability()
         } else {
                 QList<VolumeChannel> vols = m_mixdevice->playbackVolume().getVolumes().values();
                 foreach (QAbstractSlider *slider, m_slidersPlayback) {
-                        slider->setAccessibleName(slider->toolTip()+ " (" +Volume::ChannelNameReadable[vols.first().chid]+')');
+                        slider->setAccessibleName(slider->toolTip()+ " (" +Volume::channelNameReadable(vols.first().chid)+')');
                         vols.pop_front();
                 }
                 vols = m_mixdevice->captureVolume().getVolumes().values();
                 foreach (QAbstractSlider *slider, m_slidersCapture) {
-                        slider->setAccessibleName(slider->toolTip()+ " (" +Volume::ChannelNameReadable[vols.first().chid]+')');
+                        slider->setAccessibleName(slider->toolTip()+ " (" +Volume::channelNameReadable(vols.first().chid)+')');
                         vols.pop_front();
                 }
         }
