@@ -201,7 +201,7 @@ Application: KMix (kmix), signal: Segmentation fault
 
    // --- Due to the strange crash, delete everything manually : START ---------------
    // I am a bit confused why this doesn't crash. I moved the "optionsLayout->takeAt(0) delete" loop at the beginning,
-   // so the obejcts should already be deleted. ...
+   // so the objects should already be deleted. ...
 	delete configureViewButton;
 	delete restoreVolumeButton1;
 	delete restoreVolumeButton2;
@@ -402,7 +402,7 @@ QPushButton* ViewDockAreaPopup::createRestoreVolumeButton ( int storageSlot )
 {
 	QString buttonText = QString("%1").arg(storageSlot);
 	QPushButton* profileButton = new QPushButton(restoreVolumeIcon, buttonText, this);
-	profileButton->setToolTip(i18n("Load volume profile %1").arg(storageSlot));
+	profileButton->setToolTip(i18n("Load volume profile %1", storageSlot));
 	profileButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 	return profileButton;
 }
